pub enum SlopError {
InvalidLine(usize, String),
UnclosedList(usize, String),
InvalidKey(String),
Io(Error),
}Expand description
The possible errors returned by the SLOP API.
See also: SlopResult
Variants
InvalidLine(usize, String)
While parsing, the line was not a valid string KV or list KV starter.
Holds the 0-based index and contents if the line in question. The index is written as 1-based when displayed.
UnclosedList(usize, String)
While parsing, the list KV was never closed.
Holds the 0-based index and contents of the line that starts the KV. The index is written as 1-based when displayed.
InvalidKey(String)
Returned during Slop::insert if the key contains
= or ends in {.
Io(Error)
Wrapper for io::Errors.